aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--types/wlr_compositor.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/types/wlr_compositor.c b/types/wlr_compositor.c
index e7b922a5..bb4275ef 100644
--- a/types/wlr_compositor.c
+++ b/types/wlr_compositor.c
@@ -208,8 +208,12 @@ static void surface_update_damage(pixman_region32_t *buffer_damage,
pixman_region32_clear(buffer_damage);
if (pending->width != current->width ||
- pending->height != current->height) {
- // Damage the whole buffer on resize
+ pending->height != current->height ||
+ pending->viewport.src.x != current->viewport.src.x ||
+ pending->viewport.src.y != current->viewport.src.y ||
+ pending->viewport.src.width != current->viewport.src.width ||
+ pending->viewport.src.height != current->viewport.src.height) {
+ // Damage the whole buffer on resize or viewport source box change
pixman_region32_union_rect(buffer_damage, buffer_damage, 0, 0,
pending->buffer_width, pending->buffer_height);
} else {